@@ -6,7 +6,9 @@ from typing_extensions import Final
 DOCUMENT: Final[str] = 'document'
 DISPLAY_OBJECT: Final[str] = 'do'
 GRAPHICS: Final[str] = 'g'
+POINT2D: Final[str] = 'p2d'
 RECTANGLE: Final[str] = 'rect'
+POLYLINE: Final[str] = 'pline'
 SPRITE: Final[str] = 'sp'
 ARRAY: Final[str] = 'arr'
 DICTIONARY: Final[str] = 'dct'
